# Hayloft

UI tool for LLM frameworks to make easy prompt/response tracking, store and comparison of different sessions.

Install package with pip

```
pip install hayloft
```

Start hayloft server

```
hayloft start
```

Go to browser and open [http://localhost:7000](http://localhost:7000)

